@@ -18,6 +18,7 @@ from __future__ import annotations
 
 import contextlib
 import warnings
+from collections.abc import Generator, Iterable, Mapping, Sequence
 from contextlib import closing, contextmanager
 from datetime import datetime
 from functools import cached_property
@@ -25,12 +26,7 @@ from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
-    Generator,
-    Iterable,
-    List,
-    Mapping,
     Protocol,
-    Sequence,
     TypeVar,
     cast,
     overload,
@@ -45,7 +41,6 @@ from sqlalchemy.engine import Inspector
 from airflow.exceptions import (
     AirflowException,
     AirflowOptionalProviderFeatureException,
-    AirflowProviderDeprecationWarning,
 )
 from airflow.hooks.base import BaseHook
 
@@ -60,60 +55,32 @@ if TYPE_CHECKING:
 
 T = TypeVar("T")
 SQL_PLACEHOLDERS = frozenset({"%s", "?"})
+WARNING_MESSAGE = """Import of {} from the 'airflow.providers.common.sql.hooks' module is deprecated and will
+be removed in the future. Please import it from 'airflow.providers.common.sql.hooks.handlers'."""
 
 
-def return_single_query_results(sql: str | Iterable[str], return_last: bool, split_statements: bool):
-    """
-    Determine when results of single query only should be returned.
+def return_single_query_results(sql: str | Iterable[str], return_last: bool, split_statements: bool | None):
+    warnings.warn(WARNING_MESSAGE.format("return_single_query_results"), DeprecationWarning, stacklevel=2)
 
-    For compatibility reasons, the behaviour of the DBAPIHook is somewhat confusing.
-    In some cases, when multiple queries are run, the return value will be an iterable (list) of results
-    -- one for each query. However, in other cases, when single query is run, the return value will be just
-    the result of that single query without wrapping the results in a list.
+    from airflow.providers.common.sql.hooks import handlers
 
-    The cases when single query results are returned without wrapping them in a list are as follows:
-
-    a) sql is string and ``return_last`` is True (regardless what ``split_statements`` value is)
-    b) sql is string and ``split_statements`` is False
-
-    In all other cases, the results are wrapped in a list, even if there is only one statement to process.
-    In particular, the return value will be a list of query results in the following circumstances:
-
-    a) when ``sql`` is an iterable of string statements (regardless what ``return_last`` value is)
-    b) when ``sql`` is string, ``split_statements`` is True and ``return_last`` is False
-
-    :param sql: sql to run (either string or list of strings)
-    :param return_last: whether last statement output should only be returned
-    :param split_statements: whether to split string statements.
-    :return: True if the hook should return single query results
-    """
-    return isinstance(sql, str) and (return_last or not split_statements)
+    return handlers.return_single_query_results(sql, return_last, split_statements)
 
 
 def fetch_all_handler(cursor) -> list[tuple] | None:
-    """Return results for DbApiHook.run()."""
-    if not hasattr(cursor, "description"):
-        raise RuntimeError(
-            "The database we interact with does not support DBAPI 2.0. Use operator and "
-            "handlers that are specifically designed for your database."
-        )
-    if cursor.description is not None:
-        return cursor.fetchall()
-    else:
-        return None
+    warnings.warn(WARNING_MESSAGE.format("fetch_all_handler"), DeprecationWarning, stacklevel=2)
+
+    from airflow.providers.common.sql.hooks import handlers
+
+    return handlers.fetch_all_handler(cursor)
 
 
 def fetch_one_handler(cursor) -> list[tuple] | None:
-    """Return first result for DbApiHook.run()."""
-    if not hasattr(cursor, "description"):
-        raise RuntimeError(
-            "The database we interact with does not support DBAPI 2.0. Use operator and "
-            "handlers that are specifically designed for your database."
-        )
-    if cursor.description is not None:
-        return cursor.fetchone()
-    else:
-        return None
+    warnings.warn(WARNING_MESSAGE.format("fetch_one_handler"), DeprecationWarning, stacklevel=2)
+
+    from airflow.providers.common.sql.hooks import handlers
+
+    return handlers.fetch_one_handler(cursor)
 
 
 class ConnectorProtocol(Protocol):
@@ -193,6 +160,7 @@ class DbApiHook(BaseHook):
 
     @cached_property
     def placeholder(self) -> str:
+        """Return SQL placeholder."""
         placeholder = self.connection_extra.get("placeholder")
         if placeholder:
             if placeholder in SQL_PLACEHOLDERS:
@@ -250,8 +218,9 @@ class DbApiHook(BaseHook):
 
         :return: the extracted uri.
         """
-        conn = self.get_connection(self.get_conn_id())
-        conn.schema = self.__schema or conn.schema
+        conn = self.connection
+        if self.__schema:
+            conn.schema = self.__schema
         return conn.get_uri()
 
     @property
@@ -532,19 +501,8 @@ class DbApiHook(BaseHook):
         If this method is not overridden, the result data is returned as-is. If the output of the cursor
         is already a common data structure, this method should be ignored.
         """
-        # Back-compatibility call for providers implementing old ´_make_serializable' method.
-        with contextlib.suppress(AttributeError):
-            result = self._make_serializable(result=result)  # type: ignore[attr-defined]
-            warnings.warn(
-                "The `_make_serializable` method is deprecated and support will be removed in a future "
-                f"version of the common.sql provider. Please update the {self.__class__.__name__}'s provider "
-                "to a version based on common.sql >= 1.9.1.",
-                AirflowProviderDeprecationWarning,
-                stacklevel=2,
-            )
-
         if isinstance(result, Sequence):
-            return cast(List[tuple], result)
+            return cast(list[tuple], result)
         return cast(tuple, result)
 
     def _run_command(self, cur, sql_statement, parameters):
